@@ -31,8 +31,8 @@ fn generate_key_snippet(key_args: &[MethodArgument], identifier: &str) -> proc_m
 }
 
 pub fn generate_getter_impl(m: &Method, identifier: &str) -> proc_macro2::TokenStream {
-	let msig = method_gen::generate_sig(&m);
-	let key_snippet = generate_key_snippet(&m.method_args.as_slice(), identifier);
+	let msig = method_gen::generate_sig(m);
+	let key_snippet = generate_key_snippet(m.method_args.as_slice(), identifier);
 	match m.return_type.clone() {
 		syn::ReturnType::Default => panic!("getter should return some value"),
 		syn::ReturnType::Type(_, _ty) => {
@@ -47,7 +47,7 @@ pub fn generate_getter_impl(m: &Method, identifier: &str) -> proc_macro2::TokenS
 }
 
 pub fn generate_setter_impl(m: &Method, identifier: &str) -> proc_macro2::TokenStream {
-	let msig = method_gen::generate_sig(&m);
+	let msig = method_gen::generate_sig(m);
 	if m.method_args.is_empty() {
 		panic!("setter must have at least one argument, for the value");
 	}
@@ -67,8 +67,8 @@ pub fn generate_setter_impl(m: &Method, identifier: &str) -> proc_macro2::TokenS
 }
 
 pub fn generate_mapper_impl(m: &Method, identifier: &str) -> proc_macro2::TokenStream {
-	let msig = method_gen::generate_sig(&m);
-	let key_snippet = generate_key_snippet(&m.method_args.as_slice(), identifier);
+	let msig = method_gen::generate_sig(m);
+	let key_snippet = generate_key_snippet(m.method_args.as_slice(), identifier);
 	match m.return_type.clone() {
 		syn::ReturnType::Default => panic!("getter should return some value"),
 		syn::ReturnType::Type(_, ty) => {
@@ -86,8 +86,8 @@ pub fn generate_mapper_impl(m: &Method, identifier: &str) -> proc_macro2::TokenS
 }
 
 pub fn generate_is_empty_impl(m: &Method, identifier: &str) -> proc_macro2::TokenStream {
-	let msig = method_gen::generate_sig(&m);
-	let key_snippet = generate_key_snippet(&m.method_args.as_slice(), identifier);
+	let msig = method_gen::generate_sig(m);
+	let key_snippet = generate_key_snippet(m.method_args.as_slice(), identifier);
 	quote! {
 		#msig {
 			#key_snippet
@@ -97,11 +97,11 @@ pub fn generate_is_empty_impl(m: &Method, identifier: &str) -> proc_macro2::Toke
 }
 
 pub fn generate_clear_impl(m: &Method, identifier: &str) -> proc_macro2::TokenStream {
-	let msig = method_gen::generate_sig(&m);
+	let msig = method_gen::generate_sig(m);
 	if m.return_type != syn::ReturnType::Default {
 		panic!("storage clear should not return anything");
 	}
-	let key_snippet = generate_key_snippet(&m.method_args.as_slice(), identifier);
+	let key_snippet = generate_key_snippet(m.method_args.as_slice(), identifier);
 	quote! {
 		#msig {
 			#key_snippet
